-- ************************************************************************** --
-- * TitanSpec.lua                                                          * --
-- *                                                                        * --
-- * By: Rothpada                                                           * --
-- ************************************************************************** --

local TITAN_SPEC_ID = "TitanSpec";
local L = LibStub("AceLocale-3.0"):GetLocale("TitanSpec", true)

local TitanSpec_currentSpec;
local TitanSpec_numSpecs;

local TitanSpec_IS_DEBUGGING = false;

-- ************************************************************************** --
-- ******************************** Titan Functions ************************* --
-- ************************************************************************** --

function TitanPanelTitanSpecButton_OnLoad(self)
     self.registry = {
          id = TITAN_SPEC_ID,
          menuText = L["TITAN_SPEC_MENU_TEXT"],
          buttonTextFunction = "TitanPanelTitanSpecButton_GetButtonText",
          tooltipTitle = L["TITAN_SPEC_TOOLTIP_TITLE"],
          tooltipTextFunction = "TitanPanelTitanSpecButton_GetTooltipText",
	  frequency = 3,
	  updateType = TITAN_PANEL_UPDATE_BUTTON,
          savedVariables = {
               ShowLabelText = 1,
          }
     };

	self:RegisterEvent("ACTIVE_TALENT_GROUP_CHANGED");
	self:RegisterEvent("CONFIRM_TALENT_WIPE");
	self:RegisterEvent("CHARACTER_POINTS_CHANGED");

     TitanSpec_currentSpec = GetActiveTalentGroup();
     TitanSpec_numSpecs = GetNumTalentGroups();

     TitanSpec_output(TITAN_SPEC_ID.." by Rothpada (Shadow Council)");
end

function TitanPanelTitanSpecButton_OnEvent(self, event, ...)
     TitanSpec_currentSpec = GetActiveTalentGroup();
     TitanSpec_numSpecs = GetNumTalentGroups();
end

function TitanPanelTitanSpecButton_OnClick(self)
	if ( TitanSpec_numSpecs > 1 ) then
		-- switch specs
		SetActiveTalentGroup(mod(TitanSpec_currentSpec+1, TitanSpec_numSpecs)); 
	end

	TitanPanelPluginHandle_OnUpdate({TITAN_SPEC_ID, TITAN_PANEL_UPDATE_ALL})
end

function TitanPanelTitanSpecButton_GetButtonText(id)
    local msg = "";

    -- Build the button text
	local b1,_,t1,_ = GetTalentTabInfo(1, false, false);
	local b2,_,t2,_ = GetTalentTabInfo(2, false, false);
	local b3,_,t3,_ = GetTalentTabInfo(3, false, false);
	
	local buildName = L["TITAN_SPEC_HYBRID"];

	if ( t1 > 50 ) then
		buildName = b1;
	elseif ( t2 > 50 ) then
		buildName = b2;
	elseif ( t3 > 50 ) then
		buildName = b3;
	end

    return L["TITAN_SPEC_BUTTON_LABEL"], format("%d: %s (%d/%d/%d)", TitanSpec_currentSpec, buildName, t1, t2, t3);
end

function TitanPanelTitanSpecButton_GetTooltipText(self)
	local tooltip = "<empty>";

	return tooltip;
end

function TitanPanelRightClickMenu_PrepareTitanSpecMenu()

end

-- ************************************************************************** --
-- ******************************** User Functions ************************** --
-- ************************************************************************** --

function TitanSpec_debug(msg)
	if TitanSpec_IS_DEBUGGING then
		TitanSpec_output(msg);
	end
end

function TitanSpec_output(msg)
    DEFAULT_CHAT_FRAME:AddMessage(msg, 1, 1, 1);
end

